unit MainUnit;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ExtCtrls, TeEngine, Series, TeeProcs, Chart;

type
  TForm1 = class(TForm)
    Chart: TChart;
    pnlBottom: TPanel;
    srMainSeries: TFastLineSeries;
    rgGroup: TRadioGroup;
    procedure rgGroupClick(Sender: TObject);
    procedure ChartZoom(Sender: TObject);
    procedure ChartUndoZoom(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
    { Private declarations }
    XData: TChartValues;
    YData: TChartValues;
    FLogarithmic : Boolean;
    procedure RedrawGrid;
    procedure SetAxisType;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

procedure TForm1.ChartUndoZoom(Sender: TObject);
begin
  RedrawGrid;
end;

procedure TForm1.ChartZoom(Sender: TObject);
begin
  RedrawGrid;
end;

procedure TForm1.FormCreate(Sender: TObject);
const DataLen = 400000;
var Idx: Integer;
begin
   SetLength(XData, DataLen);
   SetLength(YData, DataLen);

   for Idx := 0 to DataLen-1 do
   begin
    XData[Idx] := Idx;
    YData[Idx] := 7000 + 3000*Sin(2*pi*Idx/DataLen) + 1000 *Sin (6*pi*Idx/DataLen) + 500 *Sin (12*pi*Idx/DataLen);;
   end;

   with srMainSeries.XValues do
   begin
      Value := TChartValues(XData);
      Count := DataLen;
      Modified := True;
   end;

   with srMainSeries.YValues do
   begin
      Value := TChartValues(YData);
      Count := DataLen;
      Modified := True;
   end;
end;

procedure TForm1.RedrawGrid;
var tmpIncrement, tmpValue: double;
    AxisItem: TAxisItem;
    Idx: integer;
begin
  with Chart.Axes.Bottom do
  begin
    tmpIncrement := Abs(Minimum - Maximum)/10;
    Items.Clear;
    tmpValue:=Minimum;
    while tmpValue <= Maximum do
    begin
      with Items.Add(tmpValue) do
      begin
        Text := Format('%5.2f' ,[tmpValue]);
        Font.Color := clBlack;
      end;
      tmpValue:=tmpValue+tmpIncrement;
    end;

//   if (FLogarithmic) then Items.Clear;
  end;

  with  Chart.Axes.Left do
  begin
    tmpIncrement := Abs(Minimum - Maximum)/10;
    Items.Clear;
    tmpValue:=Minimum;
    while tmpValue <= Maximum do
    begin
      with Items.Add(tmpValue) do
      begin
        Text := Format('%5.2f' ,[tmpValue]);
        Font.Color := clBlack;
      end;
      tmpValue:=tmpValue+tmpIncrement;
    end;
  end;

end;

procedure TForm1.rgGroupClick(Sender: TObject);
begin
  FLogarithmic := rgGroup.ItemIndex > 0;
  SetAxisType;
end;

procedure TForm1.SetAxisType;
begin
  with Chart.Axes.Bottom do
  begin
    Logarithmic := FLogarithmic;

    if FLogarithmic  then
    begin
      Title.Caption := 'Logarithmic';
      MinorTickCount := 8;
      MinorGrid.Visible := true;
      MinorGrid.Style := psDot;
      MinorGrid.Color := clGray;
      Grid.Style := psDot;
      AxisValuesFormat := '00e-0';
      LabelsExponent := true;
      SetMinMax(0, 400000);
      Increment := 0;
    end
    else
    begin
      Title.Caption := 'Linear';
      MinorTickCount := 0;
      MinorGrid.Visible := false;
      MinorGrid.Style := psDot;
      MinorGrid.Color := clGray;
      Grid.Style := psDot;
      AxisValuesFormat := '#,##0.###';
      LabelsExponent := false;
      SetMinMax(0, 400000);
      Increment := (400000) / 10;
    end;
  end;

  RedrawGrid;
end;

end.
